@@ -1,5 +1,5 @@
 /*
- * T.C.F.S. Utils 2.0 $Revision: 2.0 $
+ * T.C.F.S. Utils 2.0 $Revision: 2.1 $
  *
  * Authors:	Giuseppe Cattaneo, <cattaneo@udsab.dia.unisa.it>
  *		Giuseppe Persiano, <giuper@udsab.dia.unisa.it>
@@ -22,22 +22,22 @@
  */
 
 /*
- *       $Source: /home/anidel/Wip/TCFS-2.2.0a/tcfslib-0.2/src/RCS/des.c,v $
+ *       $Source: /home/anidel/Wip/TCFS-2.2.0a/tcfslib-0.3/src/RCS/des.c,v $
  *        $State: Exp $
  *
- *     $Revision: 2.0 $
+ *     $Revision: 2.1 $
  *       $Author: anidel $
- *         $Date: 1998/10/22 08:37:36 $
+ *         $Date: 1999/01/20 17:15:08 $
  *       $Locker:  $
  */
 
-static const char *RCSid="$Id: des.c,v 2.0 1998/10/22 08:37:36 anidel Exp $";
+static const char *RCSid="$Id: des.c,v 2.1 1999/01/20 17:15:08 anidel Exp $";
 /* -+-_== */ 
 
 /* Copyright (C) 1992 Eric Young - see COPYING for more details */
 /* Collected and modified by Werner Almesberger */
 
-#include <linux/kdes.h>
+#include <kdes.h>
 
 /* from des.h */
 
