@@ -1,5 +1,5 @@
 /*
- * T.C.F.S. Utils 2.0 $Revision: 2.2 $
+ * T.C.F.S. Utils 2.0 $Revision: 2.3 $
  *
  * Authors:	Giuseppe Cattaneo, <cattaneo@udsab.dia.unisa.it>
  *		Giuseppe Persiano, <giuper@udsab.dia.unisa.it>
@@ -22,16 +22,16 @@
  */
 
 /*
- *       $Source: /home/anidel/Wip/TCFS-2.2.0a/tcfslib-0.2/src/RCS/pam_tcfs.c,v $
+ *       $Source: /home/anidel/Wip/TCFS-2.2.0a/tcfslib-0.3/src/RCS/pam_tcfs.c,v $
  *        $State: Exp $
  *
- *     $Revision: 2.2 $
+ *     $Revision: 2.3 $
  *       $Author: anidel $
- *         $Date: 1998/12/01 15:07:33 $
+ *         $Date: 1999/01/20 17:15:33 $
  *       $Locker:  $
  */
 
-static const char *RCSid="$Id: pam_tcfs.c,v 2.2 1998/12/01 15:07:33 anidel Exp $";
+static const char *RCSid="$Id: pam_tcfs.c,v 2.3 1999/01/20 17:15:33 anidel Exp $";
 /* -+-_== */ 
 
 #define PAM_SM_AUTH
@@ -52,7 +52,7 @@ pam_sm_authenticate (pam_handle_t * pamh, int flags, int argc
   int r, retval, dummy;
   char *p, *u;
   static char *tk;
-  static struct tcfspwdb_r t;
+  static struct tcfspwdb_r *t;
 
   r = pam_get_item (pamh, PAM_USER, (const void**)&u);
   if (r != PAM_SUCCESS)
@@ -82,7 +82,7 @@ pam_sm_authenticate (pam_handle_t * pamh, int flags, int argc
       exit (1);
     }
 
-  tcfs_decrypt_key (u, p, t.upw, tk);
+  tcfs_decrypt_key (u, p, (unsigned char *)t->upw, (unsigned char *)tk, USERKEY);
 
   retval = pam_set_data (pamh, "tcfskey", tk, 0);
   if (retval != PAM_SUCCESS)
@@ -175,7 +175,7 @@ pam_sm_open_session (pam_handle_t * pamh, int flags, int argc
     }
 
 
-  retval = tcfs_enable (u, p);
+  retval = tcfs_enable (u, (unsigned char *)p);
   if (retval)
     {
       syslog (LOG_INFO, "starting tcfs session user %s", u);
